pub struct LoadProfList {
pub ssv: Vec<Substation>,
}Fields
ssv: Vec<Substation>Trait Implementations
Sourceimpl Clone for LoadProfList
impl Clone for LoadProfList
Sourcefn clone(&self) -> LoadProfList
fn clone(&self) -> LoadProfList
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadProfList
impl Debug for LoadProfList
Sourceimpl Default for LoadProfList
impl Default for LoadProfList
Sourcefn default() -> LoadProfList
fn default() -> LoadProfList
Returns the “default value” for a type. Read more
Sourceimpl Display for LoadProfList
impl Display for LoadProfList
Sourceimpl IntoResponse for LoadProfList
impl IntoResponse for LoadProfList
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.
Sourceimpl Template for LoadProfList
impl Template for LoadProfList
Sourceconst SIZE_HINT: usize = 1268
const SIZE_HINT: usize = 1268
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for LoadProfList
impl RefUnwindSafe for LoadProfList
impl Send for LoadProfList
impl Sync for LoadProfList
impl Unpin for LoadProfList
impl UnsafeUnpin for LoadProfList
impl UnwindSafe for LoadProfList